scoring.QLQCR29(X, id="", time="")X corresponding to the patient identification numberX corresponding to the time identification numberid and time variables of dataframe X and the score obtained for each dimension. Each score is represented by one column of Y. The names of the scores are those proposed in the scoring manual. If id and time parameters are not specified, then Y only contains the scoresWhistance RN, et al. Clinical and psychometric validation of the EORTC QLQ-CR29 questionnaire module to assess health-related quality of life in patients with colorectal cancer. European journal of cancer. 2009 Nov;45(17):3017-26.